import pytest

from . import models, cms_plugins


class TestDonatePlugin:
    """
    Test case for the Donate Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.DonatePlugin()
        assert plugin.render_template == "plugins/donate.html"


class TestDonate:
    def test_build_url(self):
        """
        Test the url property outputs the correctly formatted
        url
        """
        obj = models.Donate(campaign="donate", donation_url="www.example.com",)

        assert obj.url == "www.example.com/donate/"



# Generated by Django 2.1.15 on 2020-07-14 13:41

import cms.models.fields
from django.conf import settings
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image
import giant_plugins.utils


class Migration(migrations.Migration):

    initial = True

    dependencies = [
        ("cms", "0022_auto_20180620_1551"),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
    ]

    operations = [
        migrations.CreateModel(
            name="ContentWidthImage",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_contentwidthimage",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                (
                    "alt_text",
                    models.CharField(
                        blank=True, help_text="Image name", max_length=64, null=True
                    ),
                ),
                (
                    "caption",
                    models.CharField(
                        blank=True,
                        help_text="Add a caption to the image",
                        max_length=255,
                    ),
                ),
                (
                    "image",
                    filer.fields.image.FilerImageField(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.FILER_IMAGE_MODEL,
                        verbose_name="Content Width Image",
                    ),
                ),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin",),
        ),
        migrations.CreateModel(
            name="ContentWidthVideo",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_contentwidthvideo",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                (
                    "youtube_url",
                    models.URLField(
                        help_text="Enter the full URL of the youtube video page",
                        validators=[
                            django.core.validators.URLValidator(
                                message="Please enter the full URL of the Youtube video page",
                                regex="www.youtube.com",
                                schemes=["https"],
                            )
                        ],
                    ),
                ),
                ("title", models.CharField(blank=True, max_length=128)),
                (
                    "alt_title",
                    models.CharField(
                        blank=True,
                        default=models.CharField(blank=True, max_length=128),
                        max_length=128,
                    ),
                ),
                (
                    "image",
                    filer.fields.image.FilerImageField(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.FILER_IMAGE_MODEL,
                    ),
                ),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin", models.Model),
        ),
        migrations.CreateModel(
            name="PageCard",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_pagecard",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                (
                    "external_url",
                    models.URLField(
                        blank=True, help_text="Overrides the internal link if set"
                    ),
                ),
                ("title", models.CharField(max_length=256)),
                (
                    "summary",
                    models.CharField(
                        help_text="Limited to 140 characters", max_length=140
                    ),
                ),
                (
                    "image",
                    filer.fields.image.FilerImageField(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.FILER_IMAGE_MODEL,
                    ),
                ),
                (
                    "internal_link",
                    cms.models.fields.PageField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="+",
                        to="cms.Page",
                    ),
                ),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin", models.Model),
        ),
        migrations.CreateModel(
            name="PageCardBlock",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_pagecardblock",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin",),
        ),
        migrations.CreateModel(
            name="PullQuote",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_pullquote",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                ("quote", models.TextField()),
                ("caption", models.CharField(blank=True, max_length=255)),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin",),
        ),
        migrations.CreateModel(
            name="PullQuoteBlock",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_pullquoteblock",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin",),
        ),
        migrations.CreateModel(
            name="RichText",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_richtext",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                ("text", giant_plugins.utils.RichTextField(verbose_name="Text")),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin",),
        ),
    ]



# Generated by Django 2.2 on 2021-01-14 09:34

from django.db import migrations
import giant_plugins.utils


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0009_fix_layout_choices'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagecardblock',
            name='title',
            field=giant_plugins.utils.RichTextField(blank=True),
        ),
    ]



# Generated by Django 2.2 on 2021-05-20 09:12

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0017_logo_grid'),
    ]

    operations = [
        migrations.CreateModel(
            name='ShareThisPage',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_sharethispage', serialize=False, to='cms.CMSPlugin')),
                ('linkedin', models.BooleanField(default=False, help_text='Check this to show the LinkedIn share button')),
                ('facebook', models.BooleanField(default=False, help_text='Check this to show the Facebook share button')),
                ('email', models.BooleanField(default=False, help_text='Check this to show the Email share button')),
                ('twitter', models.BooleanField(default=False, help_text='Check this to show the Twitter share button')),
                ('whatsapp', models.BooleanField(default=False, help_text='Check this to show the Whatsapp share button')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



from . import cms_plugins


class TestShareThisPagePlugin:
    """
    Test case for the Share This Page plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.ShareThisPagePlugin()
        assert plugin.render_template == "plugins/share_this_page.html"



from django.utils.module_loading import import_string
from cms.exceptions import PluginAlreadyRegistered

import_list = [
    "content_width_video",
    "content_width_image",
    "page_card",
    "pullquote",
    "rich_text",
    "hero_image",
    "donate",
    "featured_cta",
    "logo_grid",
    "share_this_page",
]

for plugin in import_list:
    try:
        import_string(f"giant_plugins.{plugin}.cms_plugins.__all__")
    except PluginAlreadyRegistered:
        pass



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import models

__all__ = ["LogoBlockPlugin", "LogoCardPlugin"]


@plugin_pool.register_plugin
class LogoBlockPlugin(CMSPluginBase):
    """
    Plugin class for the Client card block
    """

    model = models.LogoBlock
    name = "Logo Grid Block"
    render_template = "plugins/logo_grid/container.html"
    allow_children = True
    child_classes = ["LogoCardPlugin"]


@plugin_pool.register_plugin
class LogoCardPlugin(CMSPluginBase):
    """
    Plugin for client card model
    """

    model = models.LogoCard
    name = "Logo Card"
    render_template = "plugins/logo_grid/item.html"
    require_parent = True
    parent_class = ["LogoBlockPlugin"]



# Generated by Django 2.2 on 2021-05-20 07:58

import cms.models.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0016_featured_cta'),
    ]

    operations = [
        migrations.CreateModel(
            name='LogoBlock',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_logoblock', serialize=False, to='cms.CMSPlugin')),
                ('title', models.CharField(blank=True, max_length=255)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
        migrations.CreateModel(
            name='LogoCard',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_logocard', serialize=False, to='cms.CMSPlugin')),
                ('external_url', models.URLField(blank=True, help_text='Overrides the internal link if set')),
                ('name', models.CharField(blank=True, max_length=255)),
                ('internal_link', cms.models.fields.PageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='cms.Page')),
                ('logo', filer.fields.image.FilerImageField(on_delete=django.db.models.deletion.CASCADE, related_name='company_logo', to=settings.FILER_IMAGE_MODEL)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin', models.Model),
        ),
    ]



# Generated by Django 2.2 on 2021-08-06 04:42

from django.db import migrations
import django.db.models.deletion
import filer.fields.file


class Migration(migrations.Migration):

    dependencies = [
        ('filer', '0012_file_mime_type'),
        ('giant_plugins', '0018_social_share'),
    ]

    operations = [
        migrations.AddField(
            model_name='featuredcta',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='featuredcta_files', to='filer.File', verbose_name='File'),
        ),
        migrations.AddField(
            model_name='heroimage',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='heroimage_files', to='filer.File', verbose_name='File'),
        ),
        migrations.AddField(
            model_name='logocard',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='logocard_files', to='filer.File', verbose_name='File'),
        ),
        migrations.AddField(
            model_name='pagecard',
            name='file',
            field=filer.fields.file.FilerFileField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='pagecard_files', to='filer.File', verbose_name='File'),
        ),
    ]



from cms.plugin_base import CMSPluginBase
from django.utils.module_loading import import_string

from django.conf import settings


class ExtendedPluginBase(CMSPluginBase):
    """
    An extension of the plugin base to allow us to
    use getattr calls for some of the fields such as 
    form/formfields
    """

    def __init__(self, *args, **kwargs):
        super().__init__(*args, **kwargs)
        if hasattr(settings, f"{self.get_upper_class_name()}_FORM"):
            self.form = self.get_form_class()

    def get_form_class(self):
        """
        Returns the form class to use with the plugin
        """
        return import_string(getattr(settings, f"{self.get_upper_class_name()}_FORM"))

    @classmethod
    def get_upper_class_name(cls):
        """
        Returns the uppercase of the class name
        as this is how it'll be set in the settings
        """
        return cls.__name__.upper()



# Generated by Django 2.2 on 2021-01-05 08:05

import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("giant_plugins", "0007_auto_20200930_0750"),
    ]

    operations = [
        migrations.AddField(
            model_name="contentwidthvideo",
            name="alternate_url",
            field=models.URLField(
                blank=True,
                help_text="This will be used if no Youtube URL is provided",
                null=True,
            ),
        ),
        migrations.AddField(
            model_name="pagecardblock",
            name="layout",
            field=models.CharField(default="left_right", max_length=255),
        ),
        migrations.AlterField(
            model_name="contentwidthvideo",
            name="youtube_url",
            field=models.URLField(
                blank=True,
                help_text="Enter the full URL of the youtube video page",
                null=True,
                validators=[
                    django.core.validators.URLValidator(
                        message="Please enter the full URL of the Youtube video page",
                        regex="www.youtube.com",
                        schemes=["https"],
                    )
                ],
            ),
        ),
    ]



from . import cms_plugins, models


class TestLogoModels:
    def test_block_str(self):
        """
        Test the string representation of the plugin
        """

        plugin = models.LogoBlock(pk=1)
        assert str(plugin) == "Logo block 1"

    def test_card_str(self):
        """
        Test the string representation of the plugin
        """

        plugin = models.LogoCard(pk=1)
        assert str(plugin) == "Logo card 1"

    def test_absolute_url_link(self):
        """
        Test bool is True when link is set
        """
        plugin = models.LogoCard(external_url="www.example.com")
        assert plugin.get_absolute_url()
        assert plugin.get_absolute_url() == "www.example.com"


class TestLogoPlugins:
    def test_block_template(self):
        """
        Test that the template of the block plugin is correct
        """
        container_plugin = cms_plugins.LogoBlockPlugin()
        assert container_plugin.render_template == "plugins/logo_grid/container.html"

    def test_card_template(self):
        """
        Test that the template of the card plugin is correct
        """
        item_plugin = cms_plugins.LogoCardPlugin()
        assert item_plugin.render_template == "plugins/logo_grid/item.html"



import pytest

from . import cms_plugins, models


class TestPageCardPlugin:
    """
    Test case for the PageCard Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.PageCardPlugin()
        assert plugin.render_template == "plugins/page_card/item.html"

    def test_block_template(self):
        """
        Test that the template of the plugin block is correct
        """
        plugin = cms_plugins.PageCardBlockPlugin()
        assert plugin.render_template == "plugins/page_card/container.html"


@pytest.mark.django_db
class TestPageCardModel:
    """
    Test case for the PageCard Model
    """

    def test_str(self):
        obj = models.PageCard.objects.create()
        assert str(obj) == "Page Card #1"



import pytest

from . import cms_plugins, models


class TestPageCardPlugin:
    """
    Test case for the pullquote Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.PullQuotePlugin()
        assert plugin.render_template == "plugins/pullquote/item.html"

    def test_block_template(self):
        """
        Test that the template of the plugin block is correct
        """
        plugin = cms_plugins.PullQuoteBlockPlugin()
        assert plugin.render_template == "plugins/pullquote/container.html"


@pytest.mark.django_db
class TestPageCardModel:
    """
    Test case for the pullquote Model
    """

    def test_str(self):
        obj = models.PullQuote.objects.create()
        assert str(obj) == "Pull quote 1"



from cms.plugin_pool import plugin_pool

from giant_plugins.mixins import ExtendedPluginBase

from . import models

__all__ = ["HeroImagePlugin"]


@plugin_pool.register_plugin
class HeroImagePlugin(ExtendedPluginBase):
    """
    CMS plugin for the Image Hero model
    """

    model = models.HeroImage
    name = "Image Hero"
    render_template = "plugins/hero_image.html"



# Generated by Django 2.2 on 2021-03-08 04:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0013_auto_20210225_0334'),
    ]

    operations = [
        migrations.CreateModel(
            name='Donate',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_donate', serialize=False, to='cms.CMSPlugin')),
                ('campaign', models.CharField(max_length=255)),
                ('donation_url', models.URLField()),
                ('title', models.CharField(blank=True, max_length=255)),
                ('text', models.TextField(blank=True)),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin',),
        ),
    ]



"""Contains classes which are required for some of the plugins"""
import json

from typing import Optional

from django.conf import settings
from django.contrib.admin import options
from django.core.serializers.json import DjangoJSONEncoder
from django.db import models
from django.forms import Media, Textarea
from django.forms.utils import flatatt
from django.utils.encoding import force_text
from django.utils.functional import Promise
from django.utils.safestring import mark_safe


def get_setting(setting: str) -> Optional[object]:
    """Return the provided setting, or None."""
    return getattr(settings, setting, None)


class LazyEncoder(DjangoJSONEncoder):
    def default(self, obj):
        if isinstance(obj, Promise):
            return force_text(obj)
        return super().default(obj)


class SummernoteWidget(Textarea):
    """
    Used to render WYSIWYG into the backend of the site.
    """

    def __init__(self, attrs=None, editor_options=None):
        super().__init__(attrs)
        self.editor_options = (
            editor_options or get_setting("WYSIWYG_CONFIG") or get_setting("SUMMERNOTE_CONFIG")
        )

    def render(self, name, value, attrs=None, renderer=None):
        if value is None:
            value = ""
        attrs["data-config"] = self.js_config
        cls = attrs.get("class", "")
        attrs["class"] = (
            cls + " uninitialised wysiwyg-init" if cls else "uninitialised wysiwyg-init"
        )
        final_attrs = self.build_attrs(self.attrs, attrs, name=name)
        return mark_safe(f"<textarea{flatatt(final_attrs)}>\r\n{force_text(value)}</textarea>")

    def build_attrs(self, base_attrs, extra_attrs=None, **kwargs):
        """
        Helper function for building an attribute dictionary.
        This is combination of the same method from Django<=1.10 and Django1.11+
        """
        attrs = dict(base_attrs, **kwargs)
        if extra_attrs:
            attrs.update(extra_attrs)
        return attrs

    @property
    def js_config(self):
        """
        Outputs config as JSON object for redactor.js to load
        """
        return json.dumps(self.editor_options, cls=LazyEncoder)

    @property
    def media(self):
        """
        Returns media files for django to output
        """
        css = {"all": ("vendor/summernote/summernote-lite.min.css",)}
        js = (
            "vendor/summernote/summernote-lite.min.js",
            "vendor/summernote/init.js",
        )

        return Media(css=css, js=js)


class RichTextField(models.TextField):
    """
    Override the default widget for Textfield to use Summernote WYSIWYG
    """

    def formfield(self, **kwargs):
        defaults = {"widget": get_setting("WYSIWYG_WIDGET") or SummernoteWidget}
        defaults.update(kwargs)
        return super().formfield(**defaults)


options.FORMFIELD_FOR_DBFIELD_DEFAULTS[RichTextField] = {
    "widget": get_setting("WYSIWYG_WIDGET") or SummernoteWidget
}



import pytest

from . import cms_plugins, models


class TestPageCardPlugin:
    """
    Test case for the Rich Text Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.RichTextPlugin()
        assert plugin.render_template == "plugins/rich_text.html"


@pytest.mark.django_db
class TestPageCardModel:
    """
    Test case for the Rich Text Model
    """

    @pytest.fixture
    def plugin_instance(self):
        return models.RichText(
            text="<p>Lorem ipsum dolor sit amet, consectetur adipiscing elit. "
            "Pellentesque pellentesque odio vel eros tempor bibendum."
            "Sed consequat cursus sapien vel ultricies."
            "Duis lorem lorem, ornare.</p>"
        )

    def test_str(self, plugin_instance):
        """
        Test string property
        """
        instance = plugin_instance
        assert str(instance) == instance.excerpt

    def test_strip_tags(self, plugin_instance):
        """
        Test the strip_tags property correctly removes the tags
        """
        instance = plugin_instance

        assert "<p>" not in instance.plain_text

    def test_excerpt(self, plugin_instance):
        """
        Test the truncation method returns the correct number of words
        """

        instance = plugin_instance
        word_count = len(instance.excerpt.split())
        assert word_count <= 20



from django.db import models

from cms.models import CMSPlugin


class Donate(CMSPlugin):
    """
    Plugin for a Donate element
    """

    campaign = models.CharField(max_length=255)
    donation_url = models.URLField()
    title = models.CharField(max_length=255, blank=True)
    text = models.TextField(blank=True)

    def __str__(self):
        """
        String representation of the plugin object
        """
        return f"Donate {self.pk}. Campaign: {self.campaign}"

    @property
    def url(self):
        """
        Build URL
        """
        return f"{self.donation_url}/{self.campaign}/"



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import models

__all__ = ["DonatePlugin"]


@plugin_pool.register_plugin
class DonatePlugin(CMSPluginBase):
    """
    Donate plugin
    """

    name = "Donate"
    model = models.Donate
    render_template = "plugins/donate.html"



# Generated by Django 2.2 on 2021-05-20 07:26

import cms.models.fields
from django.db import migrations, models
import django.db.models.deletion
import giant_plugins.utils


class Migration(migrations.Migration):

    dependencies = [
        ('cms', '0022_auto_20180620_1551'),
        ('giant_plugins', '0015_replace_null_with_default'),
    ]

    operations = [
        migrations.CreateModel(
            name='FeaturedCTA',
            fields=[
                ('cmsplugin_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, related_name='giant_plugins_featuredcta', serialize=False, to='cms.CMSPlugin')),
                ('external_url', models.URLField(blank=True, help_text='Overrides the internal link if set')),
                ('title', giant_plugins.utils.RichTextField()),
                ('caption', models.CharField(blank=True, max_length=255)),
                ('cta_text', models.CharField(max_length=255)),
                ('internal_link', cms.models.fields.PageField(blank=True, null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to='cms.Page')),
            ],
            options={
                'abstract': False,
            },
            bases=('cms.cmsplugin', models.Model),
        ),
    ]



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import models

__all__ = ["ShareThisPagePlugin"]


@plugin_pool.register_plugin
class ShareThisPagePlugin(CMSPluginBase):
    """
    Share this page plugin
    """

    name = "Share This Page"
    model = models.ShareThisPage
    render_template = "plugins/share_this_page.html"



# flake8: noqa
from .content_width_image.tests import *
from .content_width_video.tests import *
from .page_card.tests import *
from .pullquote.tests import *
from .rich_text.tests import *
from .hero_image.tests import *
from .donate.tests import *
from .featured_cta.tests import *
from .logo_grid.tests import *
from .share_this_page.tests import *



from django.db import models

from cms.models import CMSPlugin
from filer.fields.image import FilerImageField


class ContentWidthImage(CMSPlugin):
    """
    Represents an image object
    """

    image = FilerImageField(
        related_name="+", verbose_name="Content Width Image", on_delete=models.SET_NULL, null=True,
    )
    alt_text = models.CharField(max_length=64, help_text="Image name", blank=True, default="")
    caption = models.CharField(max_length=255, help_text="Add a caption to the image", blank=True)

    def __str__(self):
        """
        String representation of the object
        """
        return f"Content Width Image {self.pk}"



# Generated by Django 2.2 on 2021-01-29 09:29

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0010_add_title_to_pagecard'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagecard',
            name='image',
            field=filer.fields.image.FilerImageField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.FILER_IMAGE_MODEL),
        ),
    ]



from cms.plugin_pool import plugin_pool

from giant_plugins.mixins import ExtendedPluginBase

from . import models

__all__ = ["ContentWidthImagePlugin"]


@plugin_pool.register_plugin
class ContentWidthImagePlugin(ExtendedPluginBase):
    """
    Image plugin
    """

    name = "Content Width Image"
    model = models.ContentWidthImage
    render_template = "plugins/content_width_image.html"



# Generated by Django 2.2 on 2021-02-25 03:34

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0012_pagecard_cta_text'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagecardblock',
            name='background_colour',
            field=models.CharField(choices=[('dark', 'Dark'), ('light', 'Light')], default='light', max_length=30),
        ),
        migrations.AddField(
            model_name='pagecardblock',
            name='theme',
            field=models.CharField(choices=[('full-width', 'Full width'), ('content-width', 'Content width')], default='content-width', max_length=50),
        ),
    ]



# Generated by Django 2.2 on 2021-03-08 05:17

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0014_add_donate_plugin'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentwidthimage',
            name='alt_text',
            field=models.CharField(blank=True, default='', help_text='Image name', max_length=64),
        ),
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_text',
            field=models.CharField(blank=True, default='', max_length=128),
        ),
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_title',
            field=models.CharField(blank=True, default='', max_length=128),
        ),
    ]



import pytest

from . import cms_plugins, models


class TestContentWidthImagePlugin:
    """
    Test case for the ContentWidthImage Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.ContentWidthImagePlugin()
        assert plugin.render_template == "plugins/content_width_image.html"


@pytest.mark.django_db
class TestContentWidthImageModel:
    """
    Test case for the ContentWidthImage Model
    """

    def test_str(self):
        obj = models.ContentWidthImage.objects.create()
        assert str(obj) == "Content Width Image 1"



from django.core.exceptions import ValidationError
from django.db import models

from cms.models import CMSPlugin
from giant_plugins.utils import RichTextField
from mixins.models import URLMixin

__all__ = ["FeaturedCTA"]


class FeaturedCTA(CMSPlugin, URLMixin):
    """
    Model for the featured cta plugin
    """

    title = RichTextField()
    caption = models.CharField(max_length=255, blank=True)
    cta_text = models.CharField(max_length=255)

    def __str__(self):
        """
        String representation of the object
        """
        return f"Featured CTA {self.pk}"

    def clean(self):
        """
        Ensure user selects either internal or external url
        """

        if not self.internal_link and not self.external_url:
            raise ValidationError("Please either choose a page or add a custom URL.")



from cms.models import CMSPlugin

from django.db import models


class ShareThisPage(CMSPlugin):
    """
    Plugin for a share this page block
    """

    linkedin = models.BooleanField(
        default=False, help_text="Check this to show the LinkedIn share button"
    )
    facebook = models.BooleanField(
        default=False, help_text="Check this to show the Facebook share button"
    )
    email = models.BooleanField(
        default=False, help_text="Check this to show the Email share button"
    )
    twitter = models.BooleanField(
        default=False, help_text="Check this to show the Twitter share button"
    )
    whatsapp = models.BooleanField(
        default=False, help_text="Check this to show the Whatsapp share button"
    )

    def __str__(self):
        """
        String representation of the Share plugin instance
        """
        return f"Share plugin {self.pk}"



# Generated by Django 2.2 on 2021-01-08 05:14

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0008_add_climatecare_fields'),
    ]

    operations = [
        migrations.AlterField(
            model_name='pagecardblock',
            name='layout',
            field=models.CharField(choices=[('stacked', 'Stacked'), ('left_right', 'Left/Right')], default='left_right', max_length=255),
        ),
    ]



from django.db import models
from django.utils.translation import ugettext as _
from filer.fields.image import FilerImageField

from cms.models import CMSPlugin


class PullQuoteBlock(CMSPlugin):
    """
    Block for the quotes to sit in
    """

    pass


class PullQuote(CMSPlugin):
    """
    Model for a pull quote plugin
    """

    quote = models.TextField()
    caption = models.CharField(max_length=255, blank=True)
    image = FilerImageField(
        related_name="+",
        blank=True,
        null=True,
        help_text="Choose an optional image",
        on_delete=models.CASCADE,
    )

    def __str__(self):
        """
        String representation of the object
        """
        return f"Pull quote {self.pk}"



from cms.plugin_pool import plugin_pool

from giant_plugins.mixins import ExtendedPluginBase

from . import models

__all__ = ["RichTextPlugin"]


@plugin_pool.register_plugin
class RichTextPlugin(ExtendedPluginBase):
    """
    Rich text plugin
    """

    name = "Rich Text"
    model = models.RichText
    render_template = "plugins/rich_text.html"



# Generated by Django 2.2 on 2020-09-14 05:07

from django.db import migrations


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0003_pullquote_image'),
    ]

    operations = [
        migrations.RemoveField(
            model_name='pullquote',
            name='image',
        ),
    ]



# Generated by Django 2.2 on 2020-08-19 03:42

from django.conf import settings
from django.db import migrations
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('giant_plugins', '0002_heroimage'),
    ]

    operations = [
        migrations.AddField(
            model_name='pullquote',
            name='image',
            field=filer.fields.image.FilerImageField(help_text='Here you can set an optional image to be displayed with the quote', null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='+', to=settings.FILER_IMAGE_MODEL),
        ),
    ]



from django.db import models

from cms.models import CMSPlugin
from filer.fields.image import FilerImageField

from mixins.models import URLMixin


class HeroImage(CMSPlugin, URLMixin):
    """
    Model for the Image Hero plugin
    """

    RATIO_SQUARE = "square"
    RATIO_4_3 = "4_3"
    RATIO_16_9 = "16_9"
    RATIO_21_9 = "21_9"
    RATIO_CHOICES = [
        (RATIO_SQUARE, "Square"),
        (RATIO_4_3, "4:3"),
        (RATIO_16_9, "16:9"),
        (RATIO_21_9, "21:9"),
    ]

    title = models.CharField(max_length=255, blank=True)
    strapline = models.CharField(max_length=255, blank=True)
    image = FilerImageField(related_name="+", on_delete=models.SET_NULL, null=True)
    height = models.CharField(
        max_length=255,
        choices=RATIO_CHOICES,
        default=RATIO_SQUARE,
        help_text="We recommend selecting the aspect ratio that most closely matches the image that you are using."
        " We will use this to aid with the image position.",
    )
    cta_text = models.CharField(max_length=255, blank=True)

    def __str__(self):
        """
        String representation of the object
        """
        return f"Hero Image {self.pk}"



# Generated by Django 2.2 on 2020-09-30 07:50

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0006_auto_20200930_0519'),
    ]

    operations = [
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_text',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
        migrations.AlterField(
            model_name='contentwidthvideo',
            name='alt_title',
            field=models.CharField(blank=True, max_length=128, null=True),
        ),
    ]



from django.utils.html import strip_tags
from django.utils.text import Truncator

from cms.models import CMSPlugin
from giant_plugins.utils import RichTextField


class RichText(CMSPlugin):
    """
    Represents rich text block using wysiwyg editor
    """

    text = RichTextField(verbose_name="Text")

    def __str__(self):
        """
        String representation of the object
        """
        return self.excerpt

    @property
    def plain_text(self):
        """
        Returns the rich text without any HTML
        """
        return strip_tags(self.text)

    @property
    def excerpt(self):
        """
        Returns an excerpt of the text in plain text
        """
        return Truncator(self.plain_text).words(num=20)



from django.db import models

from cms.models import CMSPlugin
from filer.fields.image import FilerImageField
from mixins.models import VideoURLMixin


class ContentWidthVideo(CMSPlugin, VideoURLMixin):
    """
    Represents a content width video object
    """

    image = FilerImageField(related_name="+", on_delete=models.SET_NULL, null=True)
    title = models.CharField(max_length=128, blank=True)
    alt_title = models.CharField(max_length=128, blank=True, default="")
    alt_text = models.CharField(max_length=128, blank=True, default="")
    display_image = models.BooleanField(default=True)

    def __str__(self):
        """
        String representation of the object
        """
        return f"Content Width Video {self.pk}"



# Generated by Django 2.2 on 2020-07-30 05:58

import cms.models.fields
from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        ("cms", "0022_auto_20180620_1551"),
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ("giant_plugins", "0001_initial"),
    ]

    operations = [
        migrations.CreateModel(
            name="HeroImage",
            fields=[
                (
                    "cmsplugin_ptr",
                    models.OneToOneField(
                        auto_created=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        parent_link=True,
                        primary_key=True,
                        related_name="giant_plugins_heroimage",
                        serialize=False,
                        to="cms.CMSPlugin",
                    ),
                ),
                (
                    "external_url",
                    models.URLField(
                        blank=True, help_text="Overrides the internal link if set"
                    ),
                ),
                ("title", models.CharField(blank=True, max_length=255)),
                ("strapline", models.CharField(blank=True, max_length=255)),
                (
                    "height",
                    models.CharField(
                        choices=[
                            ("square", "Square"),
                            ("4_3", "4:3"),
                            ("16_9", "16:9"),
                            ("21_9", "21:9"),
                        ],
                        default="square",
                        help_text="We recommend selecting the aspect ratio that most closely matches the image that you are using. We will use this to aid with the image position.",
                        max_length=255,
                    ),
                ),
                ("cta_text", models.CharField(blank=True, max_length=255)),
                (
                    "image",
                    filer.fields.image.FilerImageField(
                        null=True,
                        on_delete=django.db.models.deletion.SET_NULL,
                        related_name="+",
                        to=settings.FILER_IMAGE_MODEL,
                    ),
                ),
                (
                    "internal_link",
                    cms.models.fields.PageField(
                        blank=True,
                        null=True,
                        on_delete=django.db.models.deletion.CASCADE,
                        related_name="+",
                        to="cms.Page",
                    ),
                ),
            ],
            options={"abstract": False,},
            bases=("cms.cmsplugin", models.Model),
        ),
    ]



import pytest

from . import cms_plugins, models


class TestContentWidthVideoPlugin:
    """
    Test case for the ContentWidthVideo Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.ContentWidthVideoPlugin()
        assert plugin.render_template == "plugins/content_width_video.html"


@pytest.mark.django_db
class TestContentWidthVideoModel:
    """
    Test case for the ContentWidthVideo Model
    """

    def test_str(self):
        obj = models.ContentWidthVideo.objects.create()
        assert str(obj) == "Content Width Video 1"



# Generated by Django 2.2 on 2020-09-30 05:19

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0005_auto_20200916_0832'),
    ]

    operations = [
        migrations.AddField(
            model_name='contentwidthvideo',
            name='alt_text',
            field=models.CharField(blank=True, default=models.CharField(blank=True, max_length=128), max_length=128),
        ),
        migrations.AddField(
            model_name='contentwidthvideo',
            name='display_image',
            field=models.BooleanField(default=True),
        ),
    ]



from cms.plugin_base import CMSPluginBase
from cms.plugin_pool import plugin_pool

from . import models

__all__ = ["FeaturedCTAPlugin"]


@plugin_pool.register_plugin
class FeaturedCTAPlugin(CMSPluginBase):
    """
    Plugin for featured CTA
    """

    model = models.FeaturedCTA
    name = "Featured CTA"
    render_template = "plugins/featured_cta.html"



import pytest

from . import cms_plugins, models


class TestHeroImagePlugin:
    """
    Test case for the Hero Image Plugin
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.HeroImagePlugin()
        assert plugin.render_template == "plugins/hero_image.html"


@pytest.mark.django_db
class TestHeroImageModel:
    """
    Test case for the Hero Image Model
    """

    def test_str(self):
        obj = models.HeroImage(pk=1)
        assert str(obj) == "Hero Image 1"



from django.db import models

from cms.models import CMSPlugin
from filer.fields.image import FilerImageField
from mixins.models import URLMixin


class LogoBlock(CMSPlugin):
    """
    Model for the Client block plugin.
    """

    title = models.CharField(max_length=255, blank=True)

    def __str__(self):
        """
        String representation of the block plugin
        """
        return f"Logo block {self.pk}"


class LogoCard(CMSPlugin, URLMixin):
    """
    Model for the client card plugin
    """

    logo = FilerImageField(related_name="company_logo", on_delete=models.CASCADE)
    name = models.CharField(max_length=255, blank=True)

    def __str__(self):
        """
        Return a string representation of the object
        """
        return f"Logo card {self.pk}"



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['giant_plugins',
 'giant_plugins.content_width_image',
 'giant_plugins.content_width_video',
 'giant_plugins.donate',
 'giant_plugins.featured_cta',
 'giant_plugins.hero_image',
 'giant_plugins.logo_grid',
 'giant_plugins.migrations',
 'giant_plugins.page_card',
 'giant_plugins.pullquote',
 'giant_plugins.rich_text',
 'giant_plugins.share_this_page']

package_data = \
{'': ['*'],
 'giant_plugins': ['static/vendor/summernote/*',
                   'static/vendor/summernote/font/*',
                   'static/vendor/summernote/lang/*',
                   'static/vendor/summernote/plugin/databasic/*',
                   'static/vendor/summernote/plugin/hello/*',
                   'static/vendor/summernote/plugin/specialchars/*',
                   'templates/plugins/*',
                   'templates/plugins/logo_grid/*',
                   'templates/plugins/page_card/*',
                   'templates/plugins/pullquote/*']}

install_requires = \
['django-filer', 'giant-mixins>=0.3.1,<0.4.0']

setup_kwargs = {
    'name': 'giant-plugins',
    'version': '0.6.1',
    'description': 'Adds a generic list of plugins for use within projects',
    'long_description': '# Giant Plugins\n\nA re-usable package which can be used in any project that requires a base set of plugins. \n\nThis will include a small set of plugins that are used in a large number of projects, but will not necessarily cover the full requirements. It will also provide a RichText field which can be used in other areas of the project\nThe RichText field uses ![summernote](https://github.com/summernote/summernote/) for styling the WYSIWYG widget.\n\n## Installation\n\nTo install with the package manager, run:\n\n    $ poetry add giant-plugins\n\nYou should then add `"giant_plugins"` to the `INSTALLED_APPS` in `base.py`.  \n\nIn order to run `django-admin` commands you will need to set the `DJANGO_SETTINGS_MODULE` by running\n\n    $ export DJANGO_SETTINGS_MODULE=settings\n\n## Configuration\n\nThis application exposes the following settings:\n\n`SUMMERNOTE_CONFIG` which allows the user to configure a set of options for the redactor. For example the settings below will give you a basic setup,\n\n```\nSUMMERNOTE_CONFIG = (\n    {\n        "iframe": True,\n        "summernote": {\n            "airMode": False,\n            # Change editor size\n            "width": "100%",\n            "height": "480",\n            "lang": None,\n            "toolbar": [\n                ["style", ["style"]],\n                ["font", ["bold", "underline", "clear"]],\n                ["fontname", ["fontname"]],\n                ["color", ["color"]],\n                ["para", ["ul", "ol", "paragraph"]],\n                ["table", ["table"]],\n                ["insert", ["link", "picture", "video"]],\n                ["view", ["fullscreen", "codeview", "help"]],\n            ],\n        },\n    },\n)\n\n```\n\nIn order to specify a form to use for a specific plugin you should add something like this to your settings file:\n\n```\n<PLUGIN_NAME>_FORM = "<path.to.form.FormClass>"\n```\n\nWhere PLUGIN_NAME is the capitalised name of the plugin (e.g `TEXTWITHIMAGEPLUGIN_FORM`) and the path to the form class as a string so it can be imported.\n\n ## Preparing for release\n \n In order to prep the package for a new release on TestPyPi and PyPi there is one key thing that you need to do. You need to update the version number in the `pyproject.toml`.\n This is so that the package can be published without running into version number conflicts. The version numbering must also follow the Semantic Version rules which can be found here https://semver.org/.\n \n \n ## Publishing\n \n Publishing a package with poetry is incredibly easy. Once you have checked that the version number has been updated (not the same as a previous version) then you only need to run two commands.\n \n    $ `poetry build` \n\nwill package the project up for you into a way that can be published.\n \n    $ `poetry publish`\n\nwill publish the package to PyPi. You will need to enter the username and password for the account which can be found in the company password manager',
    'author': 'Will-Hoey',
    'author_email': 'will.hoey@giantmade.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://github.com/giantmade/giant-plugins',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'python_requires': '>=3.6,<4.0',
}


setup(**setup_kwargs)



# flake8: noqa
from .content_width_image.models import *
from .content_width_video.models import *
from .page_card.models import *
from .pullquote.models import *
from .rich_text.models import *
from .hero_image.models import *
from .donate.models import *
from .logo_grid.models import *
from .featured_cta.models import *
from .share_this_page.models import *



from cms.plugin_pool import plugin_pool

from giant_plugins.mixins import ExtendedPluginBase

from . import models

__all__ = ["PullQuotePlugin", "PullQuoteBlockPlugin"]


@plugin_pool.register_plugin
class PullQuoteBlockPlugin(ExtendedPluginBase):
    """
    Plugin base for the quote block
    """

    model = models.PullQuoteBlock
    name = "Pull Quote Block"
    render_template = "plugins/pullquote/container.html"
    allow_children = True
    child_classes = ["PullQuotePlugin"]


@plugin_pool.register_plugin
class PullQuotePlugin(ExtendedPluginBase):
    """
    Plugin base for pull quote model
    """

    model = models.PullQuote
    name = "Pull Quote"
    render_template = "plugins/pullquote/item.html"



# Generated by Django 2.2 on 2021-02-08 04:04

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('giant_plugins', '0011_auto_20210129_0929'),
    ]

    operations = [
        migrations.AddField(
            model_name='pagecard',
            name='cta_text',
            field=models.CharField(default='Read more', max_length=50),
        ),
    ]



from . import cms_plugins, models


class TestFeaturedCTAPlugin:
    """
    Test case for the featured cta
    """

    def test_template(self):
        """
        Test that the template of the plugin is correct
        """
        plugin = cms_plugins.FeaturedCTAPlugin()
        assert plugin.render_template == "plugins/featured_cta.html"


class TestFeaturedCTAModel:
    """
    Test case for the featured cta Model
    """

    def test_str(self):
        obj = models.FeaturedCTA(pk=1)
        assert str(obj) == "Featured CTA 1"



from cms.plugin_pool import plugin_pool

from giant_plugins.mixins import ExtendedPluginBase

from . import models

__all__ = ["PageCardBlockPlugin", "PageCardPlugin"]


@plugin_pool.register_plugin
class PageCardBlockPlugin(ExtendedPluginBase):
    """
    Plugin for the page card block model
    """

    model = models.PageCardBlock
    name = "Page Cards Block"
    render_template = "plugins/page_card/container.html"
    allow_children = True
    child_classes = ["PageCardPlugin"]


@plugin_pool.register_plugin
class PageCardPlugin(ExtendedPluginBase):
    """
    Plugin for page card model
    """

    model = models.PageCard
    name = "Page Card"
    render_template = "plugins/page_card/item.html"
    require_parent = True
    parent_class = ["PageCardBlockPlugin"]



from cms.plugin_pool import plugin_pool

from giant_plugins.mixins import ExtendedPluginBase

from . import models

__all__ = ["ContentWidthVideoPlugin"]


@plugin_pool.register_plugin
class ContentWidthVideoPlugin(ExtendedPluginBase):
    """
    Content width video plugin
    """

    name = "Content Width Video"
    model = models.ContentWidthVideo
    render_template = "plugins/content_width_video.html"



from django.db import models

from cms.models import CMSPlugin
from filer.fields.image import FilerImageField
from mixins.models import URLMixin
from giant_plugins.utils import RichTextField


class PageCardBlock(CMSPlugin):
    """
    Model for the page card block plugin
    """

    LAYOUT_STACKED = "stacked"
    LAYOUT_LEFT_RIGHT = "left_right"
    LAYOUT_CHOICES = ((LAYOUT_STACKED, "Stacked"), (LAYOUT_LEFT_RIGHT, "Left/Right"))

    THEME_FULL_WIDTH = "full-width"
    THEME_CONTENT_WIDTH = "content-width"
    THEME_CHOICES = ((THEME_FULL_WIDTH, "Full width"), (THEME_CONTENT_WIDTH, "Content width"))

    BG_COLOUR_DARK = "dark"
    BG_COLOUR_LIGHT = "light"
    BG_COLOUR_CHOICES = ((BG_COLOUR_DARK, "Dark"), (BG_COLOUR_LIGHT, "Light"))

    layout = models.CharField(max_length=255, choices=LAYOUT_CHOICES, default=LAYOUT_LEFT_RIGHT)

    title = RichTextField(blank=True)
    theme = models.CharField(max_length=50, choices=THEME_CHOICES, default=THEME_CONTENT_WIDTH)
    background_colour = models.CharField(
        max_length=30, choices=BG_COLOUR_CHOICES, default=BG_COLOUR_LIGHT
    )

    def __str__(self):
        """
        String representation of the object
        """
        return f"Page card container {self.pk}"


class PageCard(CMSPlugin, URLMixin):
    """
    A model for an individual page card
    """

    title = models.CharField(max_length=255)
    summary = models.CharField(max_length=140, blank=True, help_text="Limited to 140 characters")
    image = FilerImageField(related_name="+", on_delete=models.SET_NULL, null=True, blank=True)
    cta_text = models.CharField(max_length=50, default="Read more")

    def __str__(self):
        """
        String representation of the object
        """
        return f"Page Card #{self.pk}"



# Generated by Django 2.2 on 2020-09-16 08:32

from django.conf import settings
from django.db import migrations, models
import django.db.models.deletion
import filer.fields.image


class Migration(migrations.Migration):

    dependencies = [
        migrations.swappable_dependency(settings.FILER_IMAGE_MODEL),
        ('giant_plugins', '0004_remove_pullquote_image'),
    ]

    operations = [
        migrations.AddField(
            model_name='pullquote',
            name='image',
            field=filer.fields.image.FilerImageField(blank=True, help_text='Choose an optional image', null=True, on_delete=django.db.models.deletion.CASCADE, related_name='+', to=settings.FILER_IMAGE_MODEL),
        ),
        migrations.AlterField(
            model_name='pagecard',
            name='summary',
            field=models.CharField(blank=True, help_text='Limited to 140 characters', max_length=140),
        ),
        migrations.AlterField(
            model_name='pagecard',
            name='title',
            field=models.CharField(max_length=255),
        ),
    ]
